/* crttabls.sql  */
/* Created by Laurence D. Finston (LDF) 2006.07.24.  */

/*

$Id: crttabls.sql,v 1.2 2006/11/23 14:01:06 ldf Exp $

* (1) Copyright and License.

This file is part of the IWF Metadata Harvester, a package for metadata harvesting.  
Copyright (C) 2006, 2007 IWF Wissen und Medien gGmbH

The author is Laurence D. Finston.                                                   

The IWF Metadata Harvester is free software; you can redistribute it and/or modify   
it under the terms of the GNU General Public License as published by                 
the Free Software Foundation; either version 2 of the License, or                    
(at your option) any later version.                                                  

The IWF Metadata Harvester is distributed in the hope that it will be useful,        
but WITHOUT ANY WARRANTY; without even the implied warranty of                       
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                             
GNU General Public License for more details.                                         

You should have received a copy of the GNU General Public License                    
along with the IWF Metadata Harvester; if not, write to the Free Software            
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA                   

The IWF Metadata Harvester is available for downloading from the                     
following FTP server:                                                                
ftp://ftp.gwdg.de/pub/gnu2/iwfmdh/

Please send bug reports to lfinsto1@gwdg.de                                         

The author can be contacted at:                                                      

Laurence D. Finston 
Kreuzbergring 41    
D-37075 Goettingen  
Germany             

lfinsto1@gwdg.de 
s246794@stud.uni-goettingen.de                        
*/

/*
LOG

LDF 2006.07.24.
Created this file ("create_tables.sql") .

LDF 2006.10.24.
Renamed this file:
Old name:  "create_tables.sql"
New name:  "crttabls.sql"

END LOG
*/ 


/* START HERE.  LDF 2006.11.20. 

   Add these tables and/or fields:  

   Contributors:expansion

   Publishers:primary_corporate_entity    
   Publishers:primary_corporate_entity_expansion   
   
   Superordinate_Entities:title  
   Classifications:DDC_numeric                  
   Classifications:DDC_name  (Pica+ 045H / Pica3 5400 Synthetische DDC-Notation)


   Pica+ 045H / Pica3 5400 Synthetische DDC-Notation


*/


/* * (1) */

/* 
exec drop_tables
exec create_tables
exec regenerate_tables
*/

-- create 
alter
proc create_tables
as

/* ** (2) PICA_Categories  */

/*
LOG

LDF 2006.08.15.
Added this table.

END LOG
*/

create table PICA_Categories
(
   pica_category_id int identity(0, 1) not null,
   pica_plus_category_code char(7) not null default 'N/A',
   pica_3_category_code smallint null,
   description_german varchar(128) not null default 'N/A',
   description_english varchar(128) not null default 'N/A',
   constraint PK_PICA_Categories primary key (pica_category_id)
)

/* PICA_Fields  */

/*
LOG

LDF 2006.08.15.
Added this table.

END LOG
*/

create table PICA_Fields
(
   pica_field_id int identity(0, 1) not null,
   pica_plus_field_code char(7) not null default 'N/A',
   pica_3_field_code char(4) not null default 'N/A',
   description_german varchar(128) not null default 'N/A',
   description_english varchar(128) not null default 'N/A',
   constraint PK_PICA_Fields primary key (pica_field_id)
)

/* PICA_Categories_PICA_Fields  */

/*
LOG

LDF 2006.08.15.
Added this table.

END LOG
*/

create table PICA_Categories_PICA_Fields
(
   pica_category_id int references PICA_Categories(pica_category_id) not null default 0,
   pica_field_id int references PICA_Fields(pica_field_id) not null default 0,
)

/* ** (2) Sources.  */

-- drop table Sources

create table Sources
(
   source_id int identity (0, 1) not null,
   source_name varchar(128) not null default 'N/A',
   source_abbrev varchar(32) not null default 'N/A',
   source_address varchar (1024) not null default 'N/A',
   constraint PK_Sources primary key (source_id)
)

/* ** (2) Records.  */

/* 
LOG

LDF 2006.08.04.
Added the following columns:
|year_appearance_begin|,
|year_appearance_end|,
|year_appearance_rak_wb|,
|year_appearance_original|.
END LOG
*/


/* 
ELN stands for "External Library Number".
LDF 2006.08.17.

*/


-- drop table Records
create table Records
(
record_id int identity(0, 1) not null,
eln_original_entry smallint not null default 0,
eln_most_recent_change smallint not null default 0,
eln_status_change smallint not null default 0,
identification_number varchar(512) not null default 'N/A', -- Can contain non-numerals!
date_original_entry datetime, -- not null, -- Change to "not null" after testing!
date_most_recent_change datetime, -- not null, -- Change to "not null" after testing!
date_status_change datetime, -- not null, -- Change to "not null" after testing!
source_id int references Sources(source_id) not null default 0,
year_appearance_begin smallint null,
year_appearance_end smallint null, 
year_appearance_rak_wb smallint null, 
year_appearance_original smallint null, 
constraint PK_Records primary key (record_id)
)

/* ** (2) Publishers  */

/*
LOG

LDF 2006.08.14.
Added this table.

END LOG
*/

-- drop table Publishers
create table Publishers
(
   publisher_id       int identity not null,
   publisher_name varchar(256) not null default 'N/A',
   place varchar(256) not null default 'N/A',
   primary_info_source bit not null default 1,
   constraint PK_Publishers   primary key (publisher_id)
)

/* ** (2) Records_Publishers  */

/*
LOG

LDF 2006.08.14.
Added this table.

END LOG
*/

-- drop table Records_Publishers
create table Records_Publishers
(
   record_id int references Records(record_id) not null default 0,
   publisher_id int references Publishers(publisher_id) not null default 0,
   

)

/* ** (2) Database_Providers  */

/*
LOG

LDF 2006.08.14.
Added this table.

END LOG
*/

-- drop table Database_Providers
create table Database_Providers
(
   database_provider_id       int identity not null,
   database_provider_name varchar(256) not null default 'N/A',
   place varchar(256) not null default 'N/A',
   constraint PK_Database_Providers   primary key (database_provider_id)
)

/* ** (2) Records_Database_Providers  */

/*
LOG

LDF 2006.08.14.
Added this table.

END LOG
*/

-- drop table Records_Database_Providers
create table Records_Database_Providers
(
   record_id int references Records(record_id) not null default 0,
   database_provider_id int references Database_Providers(database_provider_id) not null default 0
)

/* ** (2) Bibliographic_Type_Codes  */


/*
LOG

LDF 2006.09.05.
Added this table.

END LOG
*/


/* 
exec drop_tables
exec create_tables
exec regenerate_tables

select * from Bibliographic_Type_Codes

*/

create table Bibliographic_Type_Codes
(
   bibliographic_type_code_id                       int identity(0, 1) not null,
   physical_form_code                               char(1) null,
   physical_form_material_name_english              varchar(128) null,
   physical_form_material_name_german               varchar(128) null,
   bibliographic_representation_code                char(1) null,
   bibliographic_representation_description_english varchar(128) null,
   bibliographic_representation_description_german  varchar(128) null,
   description_status_code                          char(1) null,
   description_status_description_english           varchar(64) null,
   description_status_description_german            varchar(64) null,
   constraint PK_Bibliographic_Type_Codes   primary key (bibliographic_type_code_id)
)


/* ** (2) Bibliographic_Types  */

/*
LOG

LDF 2006.08.03.
Added this table.

END LOG
*/


-- drop table Bibliographic_Types

create table Bibliographic_Types
(
   bibliographic_type_id       int identity not null,
   physical_form char(1) not null,
   bibliographic_representation char(1) not null,
   description_status char(1) not null,
   miscellaneous char(1) null,
   bibliographic_representation_refinement char(1) null,
   transliteration_code char(1) null
   constraint PK_Bibliographic_Types   primary key (bibliographic_type_id)
)


/* *** (2) Records_Bibliographic_Types  */

/*
LOG

LDF 2006.08.03.
Added this association table.

END LOG
*/


-- drop table Records_Bibliographic_Types

create table Records_Bibliographic_Types
(
     record_id  int references Records(record_id)             not null default 0,
     bibliographic_type_id  int references Bibliographic_Types(bibliographic_type_id) not null default 0
)


/* ** (2) Main_Titles  */

/*
LOG

LDF 2006.07.27.
Changed definition of |Main_Titles| table.  Added |Records_Main_Titles| table.

LDF 2006.09.05.
Changed |continuation| to |continuation_main_canonical_title|.
Added |continuation_additions_main|.

END LOG
*/


--drop table Main_Titles
create table Main_Titles
(
   main_title_id                     int identity not null,
   standard_text                     varchar(512) not null default 'N/A',
   main_canonical_title              varchar(512) not null default 'N/A',
   continuation_main_canonical_title int not null default 0,
   additions_main                    varchar(512) not null default 'N/A',
   continuation_additions_main       int not null default 0,
   additional_creator_main           varchar(512) not null default 'N/A',
   parallel_canonical_title          varchar(512) not null default 'N/A',
   additions_parallel                varchar(512) not null default 'N/A',
   additional_creator_parallel       varchar(512) not null default 'N/A',
   authorship                        varchar(512) not null default 'N/A',
   constraint PK_Main_Titles         primary key (main_title_id)
)

/* *** (3) Records_Main_Titles  */

create table Records_Main_Titles
(
   record_id  int references Records(record_id)             not null default 0,
   main_title_id  int references Main_Titles(main_title_id) not null default 0
)


/* ** (2) Authors  */

create table Authors
(
   author_id     int identity not null,
   given_name    varchar(128) not null default 'N/A',
   surname       varchar(128) not null default 'N/A',
   prefix        varchar(16)  not null default 'N/A',
   id_number_ppn bigint not null default 0,
   constraint PK_Authors primary key (author_id)
)



/* *** (3) Records_Authors  */

create table Records_Authors
(
   record_id  int references Records(record_id) not null default 0,
   author_id  int references Authors(author_id) not null default 0
)

/* ** (2) Contributors  */

create table Contributors
(
   contributor_id     int identity not null,
   given_name         varchar(128) not null default 'N/A',
   surname            varchar(128) not null default 'N/A',
   prefix             varchar(16)  not null default 'N/A',
   id_number_ppn      bigint not null default 0,
/* Add LDF 2006.11.20.*/
   
   /* expansion  */

   constraint PK_Contributors primary key (contributor_id)
)


/* *** (3) Records_Contributors  */

create table Records_Contributors
(
   record_id  int references Records(record_id) not null default 0,
   contributor_id  int references Contributors(contributor_id) not null default 0
)

/* ** (2) |Languages|  */

/*
LOG

LDF 2006.08.03.
Added this table definition.

END LOG
*/


create table Languages
(
   language_id              int identity not null,
   language_name_english    varchar(64) not null default 'N/A',
   language_name_german     varchar(64) not null default 'N/A',
   language_abbrev char(3)  not null default 'N/A'
   
   constraint PK_Languages primary key (language_id)
)

/* *** (3) Records_Languages */

/*
LOG

LDF 2006.08.03.
Added this table definition.

END LOG
*/

create table Records_Languages
(
   record_id    int not null references Records(record_id),
   language_id  int not null references Languages(language_id),
   association_type char(1) null,
   association_type_name varchar(32) not null default 'N/A'
)

/* ** (2) Physical_Descriptions  */

create table Physical_Descriptions
(
   physical_description_id int not null identity(0, 1),
   text varchar(256) not null default 'N/A',
   pica_category_id int not null references PICA_Categories(pica_category_id),
   pica_field_id    int not null references PICA_Fields(pica_field_id)
   constraint PK_Physical_Descriptions primary key (physical_description_id)
)

/* ** (2) Records_Physical_Descriptions  */

create table Records_Physical_Descriptions
(
   record_id int not null references Records(record_id),
   physical_description_id int not null references Physical_Descriptions(physical_description_id)
)

/* ** (2) Remote_Access  */

/* 
LOG

LDF 2006.08.16.
Added this table.

END LOG
*/

/*

The column |format_type| isn't called |format|, because the latter is a reserved word.
LDF 2006.08.16.

*/

create table Remote_Access
(
   remote_access_id int identity(0, 1) not null,
   license_indicator bit not null,
   format_type varchar(64) not null default 'N/A',  
   web_display_text varchar(512) not null default 'N/A',
   URL varchar(512) not null default 'N/A',
   URN varchar(512) not null default 'N/A',
   internal_remarks varchar(512) not null default 'N/A',
   constraint PK_Remote_Access primary key (remote_access_id)
)

/* ** (2) Records_Remote_Access

LDF 2006.08.16.
Added this table.

*/

create table Records_Remote_Access
(
   record_id int not null references Records(record_id),
   remote_access_id int not null references Remote_Access(remote_access_id)
)

/* ** (2) Exemplar_Production_Numbers */

/*
LOG

LDF 2006.08.17.
Added this table.

LDF 2006.08.29.
Replaced the column |exemplar_production_number|
with the columns |exemplar_production_number_numeric|
and |exemplar_production_number_text|.  Unlike 
|exemplar_production_number|, |exemplar_production_number_numeric|
can contain |NULL|.

END LOG
*/

/*

Since so little information is stored in this table,
it includes a column |record_id| which references 
|Records::record_id|.  This makes it possible to do 
without an association table.
LDF 2006.08.17.

*/

/* *** (3) Definition.  */

create table Exemplar_Production_Numbers
(
    exemplar_production_number_id int identity(0, 1) not null,
    exemplar_production_number_numeric bigint null,   
    exemplar_production_number_text varchar(64) not null default 'N/A',   
    record_id int not null references Records(record_id),
    constraint PK_Exemplar_Production_Numbers primary key (exemplar_production_number_id)
)

/* ** (2) Call_Numbers */

/*
LOG

LDF 2006.08.17.
Added this table.
END LOG
*/

create table Call_Numbers
(    
    call_number_id int identity(0, 1) not null,
    call_number varchar(128) not null default 'N/A',
    library_number smallint not null default 0,
    library_department varchar(64) not null default 'N/A',
    special_location varchar(128) not null default 'N/A',
    constraint PK_Call_Numbers primary key (call_number_id)
)

/* ** (2) Records_Call_Numbers */

/*
LOG

LDF 2006.08.17.
Added this table.
END LOG
*/

create table Records_Call_Numbers
(    
    record_id int not null references Records(record_id),
    call_number_id int not null references Call_Numbers(call_number_id)
)

/* ** (2) Access_Numbers */

/*

Since so little information is stored in this table,
it includes a column |record_id| which references 
|Records::record_id|.  This makes it possible to do 
without an association table.
LDF 2006.08.18.

*/

/*
LOG

LDF 2006.08.18.
Added this table.
END LOG
*/

create table Access_Numbers
(    
    access_number_id int identity(0, 1) not null,
    access_number varchar(128) not null default 'N/A',
    record_id int not null references Records(record_id),
    constraint PK_Access_Numbers primary key (access_number_id)
)


/* ** (2) Subject_Types  */

/* 

This table is filled completely in the stored procedure 
|regenerate_tables|.  No additional entries are created when 
|ZTest| is run.  Therefore, no default values are needed.
LDF 2006.08.21.

*/

/*
LOG

LDF 2006.08.21.
Added this table.
END LOG
*/

-- drop table Subject_Types
create table Subject_Types
(
   subject_type_id int identity(0, 1) not null,
   indicator char(1) null,
   description_german varchar(64) not null,
   description_english varchar(64) not null,
   pica3_800 bit not null,
   pica3_51xx bit not null,
   constraint PK_Subject_Types primary key (subject_type_id)
)

-- select * from Subject_Types

/* ** (2) Subjects  */


/*
LOG

LDF 2006.08.21.
Added this table.

LDF 2006.08.30.
!! BUG FIX:  Changed the named of the constraint |PK_Subject| to 
|PK_Subjects|.
END LOG
*/

-- drop table Subjects
create table Subjects
(
    subject_id int identity(0, 1) not null,
    subject_type_id int not null references Subject_Types(subject_type_id),
    subject varchar(128) not null default 'N/A',    
    id_number_ppn bigint not null default 0,
    chain_number smallint null,
    chain_link_number smallint null,
    chain_info varchar(256) not null default 'N/A',
    constraint PK_Subjects primary key (subject_id)
)

-- select * from Subjects

/* ** (2) Permutation_Patterns */


/*
LOG

LDF 2006.08.21.
Added this table.

LDF 2006.08.22.
Replaced the column |subject_id| with |subject_id_start| 
and |subject_id_end|.
END LOG
*/

-- drop table Permutation_Patterns
create table Permutation_Patterns
(
    permutation_pattern_id int identity(0, 1) not null,
    record_id int not null references Records(record_id),
    subject_id_start int not null references Subjects(subject_id),
    subject_id_end int not null references Subjects(subject_id),
    chain_number int not null,
    permutation_pattern varchar(64) not null,        
    constraint PK_Permutation_Patterns primary key (permutation_pattern_id)
)
-- select * from Permutation_Patterns

/* ** (2) Records_Subjects */

/*
LOG

LDF 2006.08.21.
Added this table.

END LOG
*/

-- drop table Records_Subjects
create table Records_Subjects
(
   record_id int references Records(record_id) not null default 0,
   subject_id int references Subjects(subject_id) not null default 0,
)



/* ** (2) Content_Summaries */


/*
LOG

LDF 2006.09.07.
Added this table.

LDF 2006.09.11.
Changed the type of |content_summary| from |varchar(256)| to |varchar(1024)|.
END LOG
*/

create table Content_Summaries
(
    content_summary_id int identity(0, 1) not null,
    record_id int not null references Records(record_id),
    continuation int not null default 0,
    content_summary varchar(1024) not null,        
    constraint PK_Content_Summaries primary key (content_summary_id)
)

/* ** (2) Temp_IDs  */

--drop table Temp_IDs
create table Temp_IDs
(
temp_id int
)


/* ** (2) Select instructions  */

/* 
select * from Sources
select * from Records
select * from Main_Titles
select * from Authors
select * from Contributors
select * from Bibliographic_Types
*/

/* ** (2) End of |create_tables| procedure definition.  */

go

/* * (1) */

-- exec drop_tables
-- exec create_tables

/* * (1) */



/* Local Variables: */
/* mode:Outline */
/* abbrev-mode:t */
/* outline-regexp:"/\\* [*\f]+" */
/* End: */
